GifyNative class

Inheritance

Constructors

GifyNative()

Properties

gifRepositoryNative → GifRepositoryNative
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
videoRepositoryNative → VideoRepositoryNative
final

Methods

createGifFromImages(List<XFile> imageFiles, {int fps = 1, int? width, int? height, bool forceOriginalAspectRatio = true, List<GifyTextMessage>? textMessages}) → Future<Uint8List?>
override
createGifFromVideo(XFile videoFile, {int fps = 1, int? width, int? height, bool forceOriginalAspectRatio = true, List<GifyTextMessage>? textMessages}) → Future<Uint8List?>
override
getFramesBytes(XFile videoFile, {int fps = 1}) → Future<List<Uint8List>?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

registerWith() → void
Registers this class as the default instance of HelloPluginPlatform.