GifyTextMessage class

Constructors

GifyTextMessage({required String text, int fontSize = 10, Color fontColor = Colors.black, double x = 0.0, double y = 0.0})
const

Properties

fontColor → Color
final
fontSize → int
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
final
x → double
final
y → double
final

Methods

asMap() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited