GifRepositoryNative class

Constructors

GifRepositoryNative()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createGifFromImages(List<XFile> rawImages, {int fps = 1, int? width, int? height, bool forceOriginalAspectRatio = true, List<GifyTextMessage>? textMessages}) → Future<Uint8List>
createGifFromVideo(XFile videoFile, {int fps = 1, int? width, int? height, bool forceOriginalAspectRatio = true, List<GifyTextMessage>? textMessages}) → Future<Uint8List>
importFont(String fontName) → Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited